@@ -204,6 +204,9 @@ def vtjsonread(jsonfile, pathaf, prm=None):
     for kag in range(nag):
         if (kag > 0):
             start, end = (agTp[kag] - agDur[kag] / 2, agTp[kag] + agDur[kag] / 2)
+            if end > max(tVec):
+                print("Warning: time vector stop too soon")
+                end = max(tVec)
             ind = [x for x in range(nPt) if tVec[x] >= start and tVec[x] <= end]
             if agP[kag] == 0 or agPhon[kag-1] == "#":
                 ind_p = [x for x in range(nPt) if tVec[x] >= end-stop_delay and 
