@@ -24,13 +24,16 @@ def special_characters(x):
     y = y.replace("x", "\\textipa{@}")
     y = y.replace("#", "\#")
     y = y.replace("_", "\_")
-    y = y.replace("~", "\~")
+    #y = y.replace("~", "\~")
     y = y.replace("Z", "\\textipa{Z}")
     y = y.replace("S", "\\textipa{S}")
     y = y.replace("O", "\\textipa{O}")
     y = y.replace("^", "\\textipa{2}")
     y = y.replace("I", "\\textipa{I}")
        
+    if "~" in y:
+       y = y.replace("~", "")
+       y = "\\textipa{\~" + y + "}"
     return y
 
 def plot_segmentation(ax, lbl, inst, limy):
