@@ -14,7 +14,9 @@ from .prosody import Pitch, Intensity
 from .utils import *
 from .pyxglos import *
 import warnings
-import statsmodels.api as sm
+with warnings.catch_warnings():
+    warnings.filterwarnings("ignore",category=FutureWarning)
+    import statsmodels.api as sm
 from librosa.core import lpc
 import parselmouth
 from .filetools import *
@@ -933,7 +935,7 @@ class SpeechAudio:
 
         fileJSON = jsonFileName.replace('.json', '') + '.json'
         with open(fileJSON, 'w') as f:
-            json.dump(idjson, f)
+            json.dump(idjson, f, indent=4)
 
     def formantestimate(self, nwin=512, novlp=None, ord_filt=25):
 
