@@ -9,7 +9,10 @@ Created on Thu Jun 25 07:54:59 2020
 import numpy as np
 import numpy.matlib
 import scipy.signal
-import statsmodels.api as sm
+import warnings
+with warnings.catch_warnings():
+    warnings.filterwarnings("ignore",category=FutureWarning)
+    import statsmodels.api as sm
 import h5py
 from sklearn import linear_model
 from .prosody import Contour
@@ -174,6 +177,7 @@ def sparse_regression(features, A_source, A_target, is_norm=True, is_res=True,
     if is_norm:
         b_m = np.mean(features, axis=0, keepdims=True)
         b_s = np.std(features, axis=0, keepdims=True)
+        b_s[b_s==0] = 1
         if feat_type == "lin":
             b_m = 0
         features = (features - b_m) / b_s
