@@ -310,7 +310,7 @@ class VtWaveguide(VtNetwork):
                     'x' : lf[kT, kF] * 1e2
                 })
         with open(fTmp, 'w') as f:
-            json.dump(idjson, f)
+            json.dump(idjson, f, indent=4)
 
     def initacoustics(self):
         """ Initialisation of the derivative and integration terms
